@@ -1,59 +1,3 @@
-create_unique_layer_node_ids <- function(identifiersA, identifiersB, layer_name) {
-    #' @title [INTERNAL] Assign node IDs to the biological identifiers across a graph layer
-    #'
-    #' @description [INTERNAL] This function takes two data frames of (biological) identifiers of nodes.
-    #' Each data frame corresponds to the identifiers of the components contained in the single-layer
-    #' network of a sample group. This function outputs the same data frames, with an added column (`node_id`)
-    #' that contains node IDs which can later be used as `name` parameter for an iGraph graph.
-    #' Node IDs begin with the defined `prefix` and an underscore. If a molecule is present in both
-    #' groups, the node ID will be the same across the whole layer, allowing to easily combine the
-    #' graphs of both groups in \code{\link[DrDimont]{generate_differential_score_graph}} to calculate
-    #' differential scores of identical nodes in both sample groups.
-    #' The function is used by the high-level wrapper \link[DrDimont]{generate_individual_graphs} to
-    #' create annotations, which uniquely define nodes across the network layer.
-    #'
-    #' @param identifiersA,identifiersB [data.frame] Containing the biological identifiers of each
-    #' group of the same network layer.
-    #' @param layer_name [string] Name of layer that the node ids are created for
-    #'
-    #' @return Returns an named list. Elements `groupA` and `groupB` contain the input
-    #' data frames with an additional column `node_id`. `both` contains all unique node IDs assigned
-    #' across the network layer.
-    #' 
-    #' @keywords internal
-    #' @export
-
-    ##### check if only 1 group given
-    if (is.null(identifiersB)){
-
-        if (sum(duplicated(identifiersA)) > 0){
-            ##### show warning if duplicated node ids given
-            message(format(Sys.time(), "[%y-%m-%d %X] "), stringr::str_interp("WARNING: Duplicate node IDs given in layer ${layer_name}, this may cause ERRORS!"))
-        }
-
-        assigned_ids <- dplyr::union(identifiersA, identifiersA) %>%
-            dplyr::mutate(node_id=paste0(layer_name, "_", dplyr::row_number()), layer=layer_name)
-
-        identifiersA <- suppressMessages(dplyr::left_join(identifiersA, assigned_ids))
-
-        return(list(groupA=identifiersA, groupB=NULL, both=assigned_ids))
-
-    } else {
-
-        if((sum(duplicated(identifiersA)) > 0)|(sum(duplicated(identifiersB)) > 0)){
-            ##### show warning if duplicated node ids given
-            message(format(Sys.time(), "[%y-%m-%d %X] "), stringr::str_interp("WARNING: Duplicate node IDs given in layer ${layer_name}, this may cause ERRORS!"))
-        }
-        assigned_ids <- dplyr::union(identifiersA, identifiersB) %>%
-            dplyr::mutate(node_id=paste0(layer_name, "_", dplyr::row_number()), layer=layer_name)
-
-        identifiersA <- suppressMessages(dplyr::left_join(identifiersA, assigned_ids))
-        identifiersB <- suppressMessages(dplyr::left_join(identifiersB, assigned_ids))
-
-        return(list(groupA=identifiersA, groupB=identifiersB, both=assigned_ids))
-    }
-}
-
 generate_reduced_graph <- function(adjacency_matrix,
                                    measurement_data,
                                    identifiers,
@@ -64,10 +8,7 @@ generate_reduced_graph <- function(adjacency_matrix,
                                    mean_number_edges=NULL,
                                    edge_density=NULL,
                                    p_value_adjustment_method='BH',
-                                   reduction_alpha=0.05,
-                                   n_threads=1,
-                                   parallel_chunk_size=10^6,
-                                   print_graph_info=TRUE){
+                                   reduction_alpha=0.05){
     #' @title [INERNAL] Generate a reduced iGraph from adjacency matrices
     #'
     #' @description [INTERNAL] A wrapper functions that calls the functions to generate a network from
@@ -83,10 +24,10 @@ generate_reduced_graph <- function(adjacency_matrix,
     #'
     #' @param adjacency_matrix [matrix] Adjacency matrix of correlations computed using \code{\link[WGCNA]{cor}} in
     #' \code{\link[DrDimont]{compute_correlation_matrices}}
-    #' @param measurement_data [data.frame] Data frame containing the respective raw data (e.g. mRNA expression data,
+    #' @param measurement_data [data.frame] Dataframe containing the respective raw data (e.g. mRNA expression data,
     #' protein abundance, etc.) to the adjacency matrix. Analyzed components (e.g. genes) in rows, samples (e.g. patients)
     #' in columns.
-    #' @param identifiers [data.frame] Data frame containing  biological identifiers and the corresponding node ID
+    #' @param identifiers [data.frame] Dataframe containing  biological identifiers and the corresponding node ID
     #' created in \code{\link[DrDimont]{compute_correlation_matrices}} via \link[DrDimont]{create_unique_layer_node_ids}.
     #' The column containing node IDs has to be named `node_id`.
     #' @param handling_missing_data ["all.obs"|"pairwise.complete.obs"] Specifying the handling
@@ -109,17 +50,11 @@ generate_reduced_graph <- function(adjacency_matrix,
     #' of the correction method applied to p-values. Passed to \link[stats]{p.adjust}. (default: "BH")
     #' @param reduction_alpha [float] A number indicating the significance value for correlation p-values
     #' during reduction. Not-significant edges are dropped. (default: 0.05)
-    #' @param n_threads [int] Number of threads for parallel computation of p-values during p-value reduction.
-    #' (default: 1)
-    #' @param parallel_chunk_size [int] Number of p-values in smallest work unit when computing in parallel
-    #' during network reduction with method `p_value`. (default: 10^6)
-    #' @param print_graph_info [bool] Specifying if a summary of the reduced graph should be printed to
-    #' the console after network generation. (default: TRUE)
     #' 
     #' @return iGraph graph object of the reduced network.
     #' 
     #' @keywords internal
-    #' @export
+    #' @noRd
 
     # network reduction
     if (reduction_method == 'p_value') {
@@ -133,8 +68,7 @@ generate_reduced_graph <- function(adjacency_matrix,
         reduced_adjacency_matrix <- network_reduction_by_p_value(adjacency_matrix,
                                                                  number_of_samples,
                                                                  p_value_adjustment_method,
-                                                                 reduction_alpha,
-                                                                 parallel_chunk_size)
+                                                                 reduction_alpha)
     }
     else if (reduction_method == 'pickHardThreshold') {
         reduced_adjacency_matrix <- network_reduction_by_pickHardThreshold(adjacency_matrix,
@@ -157,9 +91,9 @@ generate_reduced_graph <- function(adjacency_matrix,
                                      diag=FALSE,
                                      mode='undirected')
 
-    graph <- igraph::delete_edges(graph, which(is.na(igraph::E(graph)$weight)))
+    graph <- igraph::delete_edges(graph, which(igraph::E(graph)$weight == -999))
 
-    if (print_graph_info == TRUE) {graph_metrics(graph)}
+    graph_metrics(graph)
 
     # remove adjacency matrix from environment
     rm(adjacency_matrix)
@@ -176,7 +110,7 @@ sample_size <- function(measurement_data, handling_missing_data) {
     #' matrix indicating the non-NA values is returned as matrix. This implementation was adopted
     #' from \code{\link[WGCNA]{corAndPvalue}}.
     #'
-    #' @param measurement_data [data.frame] Data frame containing the respective raw data (e.g. mRNA expression data,
+    #' @param measurement_data [data.frame] Dataframe containing the respective raw data (e.g. mRNA expression data,
     #' protein abundance, etc.) to the adjacency matrix. Analyzed components (e.g. genes) in rows, samples (e.g. patients)
     #' in columns.
     #' @param handling_missing_data ["all.obs"|"pairwise.complete.obs"] Specifying the handling
@@ -190,11 +124,10 @@ sample_size <- function(measurement_data, handling_missing_data) {
     #' \code{\link[WGCNA]{corAndPvalue}}
     #' 
     #' @keywords internal
-    #' @export
+    #' @noRd
 
     if (handling_missing_data == 'all.obs') { n_samples <- dim(measurement_data)[1]
-    }
-    else if (handling_missing_data == 'pairwise.complete.obs') {
+    } else if (handling_missing_data == 'pairwise.complete.obs') {
         finMat <- !is.na(measurement_data)
         n_samples <- Rfast::Crossprod(finMat, finMat)
     }
