@@ -15,12 +15,10 @@ drdimont_settings <- function(
                         ### p-value
                         p_value_adjustment_method = "BH",
                         reduction_alpha = 0.05,
-                        n_threads = 1,
-                        parallel_chunk_size = 10^6,
-                        print_graph_info = TRUE,
                         ### interaction_score
                         conda = FALSE,
                         max_path_length = 3,
+                        num_cpus = 1,
                         int_score_mode = "auto",
                         cluster_address = "auto",
                         ### drug response score
@@ -45,9 +43,6 @@ drdimont_settings <- function(
     #' Layers may be omitted if a method is mapped to `default`, e.g,
     #' \code{handling_missing_data=list(default="pairwise.complete.obs")}. (default: all.obs)
     #'
-    #' @param print_graph_info [bool] 
-    #' Print summary of the reduced graph to the console after network generation. (default: TRUE)
-    #'
     #' @param reduction_method ["pickHardThreshold"|"p_value"]
     #' Reduction method for reducing networks. `p_value` for hard thresholding based on the statistical
     #' significance of the computed correlation. `pickHardThreshold` for a cutoff based on the scale-freeness
@@ -56,7 +51,7 @@ drdimont_settings <- function(
     #' Layers may be omitted if a method is mapped to `default`. (default: pickHardThreshold)
     #'
     #' @param r_squared_cutoff pickHardThreshold setting: [float|named list]
-    #' Minimum scale free topology fitting index R^2 for reduction using
+    #' Minimum scale-free topology fitting index R^2 for reduction using
     #' \code{\link[WGCNA]{pickHardThreshold}}.
     #' Can be a single float number if the same for all layers, else a named list mapping layer names to a cutoff
     #' (see \code{handling_missing_data} setting) or a named list in a named list mapping groupA or groupB and layer
@@ -64,14 +59,14 @@ drdimont_settings <- function(
     #' \code{r_squared_cutoff=list(groupA=list(mrna=0.85, protein=0.8), groupB=list(mrna=0.9, protein=0.85))}.
     #' Layers/groups may be omitted if a cutoff is mapped to `default`. (default: 0.85)
     #' @param cut_vector pickHardThreshold setting: [sequence of float|named list]
-    #' Vector of hard threshold cuts for which the scale free topology fit indices are calculated during
+    #' Vector of hard threshold cuts for which the scale-free topology fit indices are calculated during
     #' reduction with \code{\link[WGCNA]{pickHardThreshold}}.
     #' Can be a single regular sequence if the same for all layers, else a named list mapping layer names 
     #' to a cut vector or a named list in a named list mapping groupA or groupB and layer names to a cut 
     #' vector (see \code{r_squared_cutoff} setting). Layers/groups may be omitted if a vector is mapped
     #' to `default`. (default: seq(0.2, 0.8, by = 0.01))
     #' @param mean_number_edges pickHardThreshold setting: [int|named list] 
-    #' Maximal mean number edges threshold to find a suitable edge weight cutoff employing
+    #' Maximal mean number of edges threshold to find a suitable edge weight cutoff employing
     #' \code{\link[WGCNA]{pickHardThreshold}} to reduce the network to at most the specified mean number of edges.
     #' Can be a single int number if the same for all layers, else a named list mapping layer names to a mean number of edges or
     #' a named list in a named list mapping groupA or groupB and layer names to a cutoff (see \code{r_squared_cutoff} setting).
@@ -88,23 +83,20 @@ drdimont_settings <- function(
     #' @param reduction_alpha p_value setting: [float] 
     #' Significance value for correlation p-values
     #' during reduction. Not-significant edges are dropped. (default: 0.05)
-    #' @param n_threads p_value setting: [int] 
-    #' Number of threads for parallel computation of p-values during p-value reduction. (default: 1)
-    #' @param parallel_chunk_size p_value setting: [int] 
-    #' Number of p-values in smallest work unit when computing in parallel
-    #' during network reduction with method `p_value`. (default: 10^6)
     #'
     #' @param conda [bool] 
     #' Python installation in conda environment. Set TRUE if Python is installed with conda. (default: FALSE)
     #' @param max_path_length [int] 
     #' Integer of maximum length of simple paths to include in the
     #' \code{\link[DrDimont]{generate_interaction_score_graphs}} computation. (default: 3)
+    #' @param num_cpus [int] 
+    #' Number of CPUs to use for parallel computation for interaction scores. (default: 1)
     #' @param int_score_mode ["auto"|"sequential"|"ray"] 
-    #' Interaction score sequential or parallel ("ray") computation. For parallel computation the Python library Ray ist used. 
-    #' When set to `auto` computation depends on the  graph sizes. (default: "auto")
-    #' @param cluster_address [string] Local node IP-address of Ray if executed on a cluster.
+    #' Interaction score sequential or parallel ("ray") computation. For parallel computation, the Python library Ray is used. 
+    #' When set to `auto`, computation depends on the graph sizes. (default: "auto")
+    #' @param cluster_address [string] (deprecated; will be removed in future versions) Local node IP address of Ray if executed on a cluster.
     #' On a cluster: Start ray with \code{ray start --head --num-cpus 32} on the console before DrDimont execution.
-    #' It should work with "auto", if it does not specify IP-address given by the \code{ray start} command. (default: "auto")
+    #' It should work with "auto", if it does not specify an IP address given by the \code{ray start} command. (default: "auto")
     #'
     #' @param median_drug_response [bool] 
     #' Computation of median (instead of mean) of a drug's targets differential scores (default: FALSE)
@@ -112,7 +104,7 @@ drdimont_settings <- function(
     #' Computation of drug response scores based on absolute differential scores (instead of the actual differential
     #' scores) (default: FALSE)
     #'
-    #' @param saving_path [string] Path to save intermediate output of DrDimont's functions. Default is temporary folder.
+    #' @param saving_path [string] Path to save intermediate output of DrDimont's functions. Default: temporary folder.
     #' @param save_data [bool] 
     #' Save intermediate data such as correlation_matrices, individual_graphs, etc. during exectution of DrDimont. (default: FALSE)
     #' @param ... Supply additional settings.
@@ -132,7 +124,7 @@ drdimont_settings <- function(
     
     settings <- c(as.list(environment()), list(...))
     
-    ### check if python installed, return error if not
+    ### check if python is installed, return an error if not
     if(settings$conda){
         tryCatch({reticulate::conda_python('r-DrDimont')},
                  warning = function(e) {
@@ -164,7 +156,7 @@ get_layer_setting <- function(layer, group, settings, setting_name) {
     #' @return Setting value(s) for this layer (and group)
     #' 
     #' @keywords internal
-    #' @export
+    #' @noRd
     
     if (!is.list(settings[[setting_name]])) {return(settings[[setting_name]])}
     else if (!is.null(settings[[setting_name]][[group]][[layer]])) {return(settings[[setting_name]][[group]][[layer]])}
